@@ -103,6 +103,13 @@ static bool
 write_envelope(const sentry_path_t *path, const sentry_envelope_t *envelope)
 {
     sentry_uuid_t event_id = sentry__envelope_get_event_id(envelope);
+
+    // Generate a random UUID for the filename if the envelope has no event_id
+    // this avoids collisions on NIL-UUIDs
+    if (sentry_uuid_is_nil(&event_id)) {
+        event_id = sentry_uuid_new_v4();
+    }
+
     char *envelope_filename = sentry__uuid_as_filename(&event_id, ".envelope");
     if (!envelope_filename) {
         return false;
@@ -264,7 +271,7 @@ sentry__process_old_runs(const sentry_options_t *options, uint64_t last_crash)
                     sentry__envelope_add_session(session_envelope, session);
 
                     sentry__session_free(session);
-                    if ((++session_num) >= SENTRY_MAX_ENVELOPE_ITEMS) {
+                    if ((++session_num) >= SENTRY_MAX_ENVELOPE_SESSIONS) {
                         sentry__capture_envelope(
                             options->transport, session_envelope);
                         session_envelope = NULL;
