@@ -381,13 +381,9 @@ sentry__jsonwriter_write_int64(sentry_jsonwriter_t *jw, int64_t val)
 void
 sentry__jsonwriter_write_uint64(sentry_jsonwriter_t *jw, uint64_t val)
 {
-    // TODO currently all uint64 values should be sent as strings; update when
-    // this changes and 64-bit unsigned integers can be ingested properly
-    // see
-    // https://github.com/getsentry/sentry-native/pull/1326#discussion_r2241965997
     if (can_write_item(jw)) {
         char buf[26];
-        snprintf(buf, sizeof(buf), "\"%" PRIu64 "\"", val);
+        snprintf(buf, sizeof(buf), "%" PRIu64, val);
         write_str(jw, buf);
     }
 }
